@@ -64,9 +64,8 @@ pub struct NodeLabel {
 
 impl NodeLabel {
     pub(crate) fn hash(&self) -> Digest {
-        let byte_label_len = crate::hash::hash(&self.len.to_be_bytes());
-        let byte_label_val = crate::hash::hash(&self.val);
-        crate::hash::merge(&[byte_label_len, byte_label_val])
+        let hash_input = [&self.len.to_be_bytes()[..], &self.val].concat();
+        crate::hash::hash(&hash_input)
     }
 
     /// Takes as input a pointer to the caller and another NodeLabel,
@@ -191,7 +190,7 @@ pub struct LookupProof {
     /// The version of the record
     pub version: u64,
     /// VRF proof for the label corresponding to this version
-    pub exisitence_vrf_proof: Vec<u8>,
+    pub existence_vrf_proof: Vec<u8>,
     /// Record existence proof
     pub existence_proof: MembershipProof,
     /// VRF proof for the marker preceding (less than or equal to) this version
@@ -202,6 +201,8 @@ pub struct LookupProof {
     pub freshness_vrf_proof: Vec<u8>,
     /// Freshness proof (non member at previous epoch)
     pub freshness_proof: NonMembershipProof,
+    /// Proof for commitment value derived from raw AkdLabel and AkdValue
+    pub commitment_proof: Vec<u8>,
 }
 
 /// A vector of UpdateProofs are sent as the proof to a history query for a particular key.
@@ -238,6 +239,8 @@ pub struct UpdateProof {
     pub future_marker_vrf_proofs: Vec<Vec<u8>>,
     /// Proof that future markers did not exist
     pub non_existence_of_future_markers: Vec<NonMembershipProof>,
+    /// Proof for commitment value derived from raw AkdLabel and AkdValue
+    pub commitment_proof: Vec<u8>,
 }
 
 /// This proof is just an array of [`UpdateProof`]s.
